Wagtail OAuth2.0 Login
======================

.. image:: https://readthedocs.org/projects/aioli-client/badge/?version=latest
   :target: https://aioli-client.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/Gandi/wagtail-oauth2/actions/workflows/main.yml/badge.svg
   :target: https://github.com/Gandi/wagtail-oauth2/actions/workflows/main.yml
   :alt: Build Status


.. image:: https://codecov.io/gh/Gandi/wagtail-oauth2/branch/main/graph/badge.svg?token=VN14GVV3Y0
   :target: https://codecov.io/gh/Gandi/wagtail-oauth2
   :alt: Coverage

Plugin to replace Wagtail default login by an OAuth2.0 Authorization Server.
